@@ -23,6 +23,7 @@
 #include "askname.h"
 #include "variablesdelegate.h"
 #include "viewportwidget.h"
+#include "functionedit.h"
 #ifdef HAVE_OPENGL
 #	include "graph3d.h"
 #endif
@@ -30,7 +31,6 @@
 #include <analitzagui/operatorsmodel.h>
 #include <analitzagui/functionfactory.h>
 
-#include <analitzagui/functionedit.h>
 #include <analitzagui/functionsmodel.h>
 #include <analitzagui/functionsview.h>
 #include <analitzagui/expressionedit.h>
@@ -45,6 +45,7 @@
 #include <QTableView>
 #include <KAction>
 #include <KHTMLView>
+#include <KHelpMenu>
 #include <KFileDialog>
 #include <KMenu>
 #include <KMenuBar>
@@ -102,12 +103,14 @@ class Add3DOption : public InlineOptions
 };
 #endif
 
+QColor randomFunctionColor() { return QColor::fromHsv(qrand()%255, 255, 255); }
+
 KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 {
 	resize(900, 500);
 	
 	m_tabs = new QTabWidget(this);
-	this->setCentralWidget(m_tabs);
+	setCentralWidget(m_tabs);
 	
 	setStatusBar(new KStatusBar(this));
 	setMenuBar(new KMenuBar(this));
@@ -127,7 +130,7 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	c_results->view()->setFocusPolicy(Qt::NoFocus);
 	c_dock_vars = new QDockWidget(i18n("Variables"), this);
 	c_dock_vars->setFeatures(QDockWidget::DockWidgetFloatable|QDockWidget::DockWidgetMovable);
-	this->addDockWidget(Qt::RightDockWidgetArea, c_dock_vars);
+	addDockWidget(Qt::RightDockWidgetArea, c_dock_vars);
 	
 	c_varsModel=new VariablesModel(c_results->analitza()->variables());
 	c_varsModel->setEditable(false);
@@ -192,12 +195,13 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	b_dock_funcs = new QDockWidget(i18n("Functions"), this);
 	b_tools = new QTabWidget(b_dock_funcs);
 	b_tools->setTabPosition(QTabWidget::South);
-	this->addDockWidget(Qt::RightDockWidgetArea, b_dock_funcs);
+	addDockWidget(Qt::RightDockWidgetArea, b_dock_funcs);
 	
 	b_funcs = new FunctionsView(b_tools);
 	b_funcs->setModel(b_funcsModel);
 	b_funcs->header()->resizeSections(QHeaderView::ResizeToContents);
 	b_funcs->setSelectionMode(QAbstractItemView::SingleSelection);
+	m_graph2d->setSelectionModel(b_funcs->selectionModel());
 	
 	b_tools->addTab(b_funcs, i18n("List"));
 	
@@ -228,11 +232,11 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	c_results->addOptionsObserver(new Add2DOption(this));
 	
 	connect(b_varsModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)), SLOT(valueChanged()));
-	connect(b_funcs, SIGNAL(doubleClicked(const QModelIndex &)), this, SLOT(edit_func(const QModelIndex &)));
+	connect(b_funcs, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(edit_func(QModelIndex)));
 	connect(b_tools, SIGNAL(currentChanged(int)), this, SLOT(functools(int)));
-	connect(m_graph2d, SIGNAL(status(const QString &)), this, SLOT(changeStatusBar(const QString &)));
+	connect(m_graph2d, SIGNAL(status(QString)), this, SLOT(changeStatusBar(QString)));
 	connect(m_graph2d, SIGNAL(viewportChanged(QRectF)), b_viewport, SLOT(setViewport(QRectF)));
-	connect(b_viewport, SIGNAL(viewportChange(QRectF)), m_graph2d, SLOT(setViewport(QRectF)));
+	connect(b_viewport, SIGNAL(viewportChange(QRectF)), m_graph2d, SLOT(changeViewport(QRectF)));
 	connect(b_varsView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(varsContextMenu(QPoint)));
 	
 	////////menu
@@ -286,7 +290,7 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	t_layo->addWidget(t_exp);
 	
 	connect(t_exp,  SIGNAL(returnPressed()), this, SLOT(new_func3d()));
-	connect(m_graph3d, SIGNAL(status(const QString &)), this, SLOT(changeStatusBar(const QString &)));
+	connect(m_graph3d, SIGNAL(status(QString)), this, SLOT(changeStatusBar(QString)));
 	c_results->addOptionsObserver(new Add3DOption(this));
 	
 	////////menu
@@ -318,7 +322,7 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	//Dictionary tab
 	d_dock = new QDockWidget(i18n("Operations"), this);
 	d_dock->setFeatures(QDockWidget::DockWidgetFloatable | QDockWidget::DockWidgetMovable);
-	this->addDockWidget(Qt::RightDockWidgetArea, d_dock);
+	addDockWidget(Qt::RightDockWidgetArea, d_dock);
 	Dictionary *dic = new Dictionary(m_tabs);
 	m_tabs->addTab(dic, i18n("&Dictionary"));
 	
@@ -327,8 +331,8 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	d_filter=new KLineEdit(w);
 	d_filter->setClearButtonShown(true);
 	d_filter->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
-	connect(d_filter, SIGNAL(textChanged(const QString&)), dic, SLOT(setFilter(const QString&)));
-	connect(d_filter, SIGNAL(textChanged(const QString&)), this, SLOT(dictionaryFilterChanged(const QString&)));
+	connect(d_filter, SIGNAL(textChanged(QString)), dic, SLOT(setFilter(QString)));
+	connect(d_filter, SIGNAL(textChanged(QString)), this, SLOT(dictionaryFilterChanged(QString)));
 	d_list = new QListView(w);
 	d_list->setModel(dic->model());
 	d_list->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding));
@@ -337,15 +341,16 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	leftLayo->addWidget(d_list);
 	d_dock->setWidget(w);
 	
-	connect(d_list->selectionModel(), SIGNAL(currentChanged (QModelIndex, QModelIndex)),
-		dic, SLOT(activated(QModelIndex , QModelIndex)));
+	connect(d_list->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
+		dic, SLOT(activated(QModelIndex,QModelIndex)));
 	
 	//EODictionary
 	//Ego's reminder
-	menuBar()->addMenu(helpMenu());
+	KHelpMenu* help = new KHelpMenu(this, KGlobal::mainComponent().aboutData());
+	menuBar()->addMenu(help->menu());
 	
-	connect(b_funcsModel, SIGNAL(functionModified(QString, Analitza::Expression)),
-			c_results, SLOT(modifyVariable(QString, Analitza::Expression)));
+	connect(b_funcsModel, SIGNAL(functionModified(QString,Analitza::Expression)),
+			c_results, SLOT(modifyVariable(QString,Analitza::Expression)));
 	connect(b_funcsModel, SIGNAL(functionRemoved(QString)),
 			c_results, SLOT(removeVariable(QString)));
 	
@@ -384,7 +389,7 @@ void KAlgebra::add2D(const Analitza::Expression& exp)
 {
 	qDebug() << "adding" << exp.toString();
 	
-	Function f(b_funcsModel->freeId(), exp, c_results->analitza()->variables(), QPen(Qt::blue), 6, 0);
+	Function f(b_funcsModel->freeId(), exp, c_results->analitza()->variables(), QPen(randomFunctionColor()), 6, 0);
 	b_funcsModel->addFunction(f);
 	
 	m_tabs->setCurrentIndex(1);
@@ -403,7 +408,7 @@ void KAlgebra::new_func()
 	b_funced->setEditing(false);
 	b_funced->clear();
 	b_tools->setCurrentIndex(0);
-	b_funcsModel->setSelected(f.name());
+	b_funcs->setCurrentIndex(b_funcsModel->indexForId(f.name()));
 	m_graph2d->setFocus();
 }
 
@@ -423,7 +428,7 @@ void KAlgebra::functools(int i)
 		b_tools->setTabText(1, i18n("&Add"));
 	else {
 		b_funced->setName(b_funcsModel->freeId());
-		b_funced->setColor(QColor::fromHsv(qrand()%255, 255, 255));
+		b_funced->setColor(randomFunctionColor());
 		b_funced->setEditing(false);
 		b_funced->setFocus();
 	}
@@ -622,7 +627,7 @@ void KAlgebra::tabChanged(int n)
 
 void KAlgebra::select(const QModelIndex & idx)
 {
-	b_funcsModel->setSelected(idx);
+	b_funcs->selectionModel()->setCurrentIndex(idx, QItemSelectionModel::ClearAndSelect);
 }
 
 void KAlgebra::updateInformation()
@@ -645,7 +650,7 @@ void KAlgebra::valueChanged()
 {
 	//FIXME: Should only repaint the affected ones.
 	if(b_funcsModel->rowCount()>0)
-		m_graph2d->update(b_funcsModel->index(0,0), b_funcsModel->index(b_funcsModel->rowCount()-1,0));
+		m_graph2d->updateFunctions(b_funcsModel->index(0,0), b_funcsModel->index(b_funcsModel->rowCount()-1,0));
 }
 
 void KAlgebra::varsContextMenu(const QPoint& p)
